@@ -77,7 +77,8 @@ def write_kafka_stream(stream: DataFrame, spark_job_conf: dict, output_name):
             .options(**output_conf['kafka_options']) \
             .trigger(processingTime=output_conf['processing_time']) \
             .outputMode("append") \
-            .start()
+            .start() \
+            .awaitTermination()
     elif output_conf.get('availableNow') is not None:
         stream \
             .writeStream \
@@ -87,13 +88,23 @@ def write_kafka_stream(stream: DataFrame, spark_job_conf: dict, output_name):
             .outputMode("append") \
             .start() \
             .awaitTermination()
+    elif output_conf.get("once") is not None:
+        stream \
+            .writeStream \
+            .format("kafka") \
+            .options(**output_conf['kafka_options']) \
+            .trigger(once=output_conf['availableNow']) \
+            .outputMode("append") \
+            .start() \
+            .awaitTermination()
     else:
         stream \
             .writeStream \
             .format("kafka") \
             .options(**output_conf['kafka_options']) \
             .outputMode("append") \
-            .start()
+            .start() \
+            .awaitTermination()
 
 
 ######
@@ -164,6 +175,7 @@ def write_delta(spark_job_conf: dict, output_name: str, df: DataFrame):
         .save(output_conf['delta_options']['location'])
     )
 
+
 def write_delta_no_partitioning(spark_job_conf: dict, output_name: str, df: DataFrame):
     output_conf = get_spark_conf(output_name, spark_job_conf['outputs'])
     create_delta_tables_if_not_exists(output_conf, output_conf['delta_options']['schema'])
@@ -180,15 +192,46 @@ def write_delta_no_partitioning(spark_job_conf: dict, output_name: str, df: Data
 def write_delta_stream(spark_job_conf: dict, output_name: str, stream: DataFrame):
     output_stream_conf = get_spark_conf(output_name, spark_job_conf['outputs'])
     create_delta_tables_if_not_exists(output_stream_conf, output_stream_conf['delta_options']['schema'])
-    stream \
-        .writeStream \
-        .format("delta") \
-        .outputMode("append") \
-        .trigger(availableNow=True) \
-        .partitionBy(output_stream_conf['delta_options']['partition_columns']) \
-        .option("checkpointLocation", output_stream_conf['delta_options']['checkpoint_location']) \
-        .start(output_stream_conf['delta_options']['location']) \
-        .awaitTermination()
+
+    if output_stream_conf.get('processing_time') is not None:
+        stream \
+            .writeStream \
+            .format("delta") \
+            .outputMode("append") \
+            .trigger(processingTime=output_stream_conf['processing_time']) \
+            .partitionBy(output_stream_conf['delta_options']['partition_columns']) \
+            .option("checkpointLocation", output_stream_conf['delta_options']['checkpoint_location']) \
+            .start(output_stream_conf['delta_options']['location']) \
+            .awaitTermination()
+    elif output_stream_conf.get('availableNow') is not None:
+        stream \
+            .writeStream \
+            .format("delta") \
+            .outputMode("append") \
+            .trigger(availableNow=output_stream_conf.get('availableNow')) \
+            .partitionBy(output_stream_conf['delta_options']['partition_columns']) \
+            .option("checkpointLocation", output_stream_conf['delta_options']['checkpoint_location']) \
+            .start(output_stream_conf['delta_options']['location']) \
+            .awaitTermination()
+    elif output_stream_conf.get('once') is not None:
+        stream \
+            .writeStream \
+            .format("delta") \
+            .outputMode("append") \
+            .trigger(once=output_stream_conf.get('once')) \
+            .partitionBy(output_stream_conf['delta_options']['partition_columns']) \
+            .option("checkpointLocation", output_stream_conf['delta_options']['checkpoint_location']) \
+            .start(output_stream_conf['delta_options']['location']) \
+            .awaitTermination()
+    else:
+        stream \
+            .writeStream \
+            .format("delta") \
+            .outputMode("append") \
+            .partitionBy(output_stream_conf['delta_options']['partition_columns']) \
+            .option("checkpointLocation", output_stream_conf['delta_options']['checkpoint_location']) \
+            .start(output_stream_conf['delta_options']['location']) \
+            .awaitTermination()
 
 
 def write_delta_stream_no_partitioning(spark_job_conf: dict, output_name: str, stream: DataFrame):
